################################################################
#
#   Albow - Tab Panel
#
################################################################

from pygame import Rect
from widget import Widget
from theme import ThemeProperty, FontProperty

class TabPanel(Widget):
	#  pages         [Widget]
	#  current_page  Widget

	tab_font = FontProperty('tab_font')
	tab_height = ThemeProperty('tab_height')
	tab_border_width = ThemeProperty('tab_border_width')
	tab_fg_color = ThemeProperty('tab_fg_color')
	selected_tab_bg_color = ThemeProperty('selected_tab_bg_color')
	unselected_tab_bg_color = ThemeProperty('unselected_tab_bg_color')
	
	def __init__(self, *args, **kwds):
		Widget.__init__(self, *args, **kwds)
		self.pages = []
		self.current_page = None
	
	def content_size(self):
		return (self.width, self.height - self.tab_height)
	
	def content_rect(self):
		return Rect((0, self.tab_height), self.content_size())
	
	def add_page(self, title, page):
		page.rect = self.content_rect()
		page.tab_title = title
		self.pages.append(page)
	
	def remove_page(self, page):
		try:
			i = self.pages.index(page)
			del self.pages[i]
		except IndexError:
			pass
		if page is self.current_page:
			self.show_page(None)
	
	def show_page(self, page):
		if self.current_page:
			self.remove(self.current_page)
		self.current_page = page
		if page:
			self.add(page)
			page.focus()

	def draw(self, surf):
		font = self.tab_font
		fg = self.tab_fg_color
		sel_bg_color = self.selected_tab_bg_color
		unsel_bg_color = self.unselected_tab_bg_color
		pages = self.pages
		b = self.tab_border_width
		h = self.tab_height
		x0 = 0
		for i in xrange(len(pages)):
			x1 = self.tab_boundary(i + 1)
			page = pages[i]
			selected = page is self.current_page
			if selected:
				bg = page.bg_color or sel_bg_color
			else:
				bg = page.bg_color or unsel_bg_color
			surf.fill(bg, (x0, 0, x1 - x0, h))
			surf.fill(fg, (x0, 0, b, h))
			surf.fill(fg, (x0 + b, 0, x1 - x0 - b, b))
			if not selected:
				surf.fill(fg, (x0 + b, h - b, x1 - x0 - b, b))
			buf = font.render(page.tab_title, True, page.fg_color or fg)
			r = buf.get_rect()
			r.center = ((x0 + x1) // 2, h // 2)
			surf.blit(buf, r)
			x0 = x1
		surf.fill(fg, (x0, 0, b, h))
	
	def mouse_down(self, e):
		x, y = e.pos
		if y < self.tab_height:
			i = self.tab_number_containing_x(x)
			if i is not None:
				self.show_page(self.pages[i])

	def tab_boundary(self, i):
		width = self.width - self.tab_border_width
		return width * i // len(self.pages)

	def tab_number_containing_x(self, x):
		n = len(self.pages)
		width = self.width - self.tab_border_width
		i = x * n // width
		if 0 <= i < n:
			return i
