################################################################
#
#   Assembly Line - Company page
#
################################################################

from albow.controls import Label, Row, Column, Grid, Frame, ValueView
from albow.palette_view import PaletteView
from albow.resource import get_font
from screen import ALScreen
from game import game
from format import format_dollars, format_money

#-----------------------------------------------------------------------

heading_font = get_font(15, "VeraBd.ttf")

#-----------------------------------------------------------------------

class CompanyPage(ALScreen):

	bg_color = (242, 242, 242)

	def __init__(self, shell):
		ALScreen.__init__(self, shell)
		h = self.height - 90
		stat_label = Label("Finances", font = heading_font)
		rows = [
			[Label("Cash"), CashView()],
			[Label("Income"), IncomeView()],
			[Label("Expenditure"), ExpenditureView()],
			[Label("Profit"), ProfitView()],
		]
		grid = Frame(Grid(rows), border_width = 2, margin = 10)
		finances = Column([
			stat_label,
			grid], align = 'l')
		stock_label = Label("Materials in Stock", font = heading_font)
		stock = Column([
			stock_label,
			StockView(h - stock_label.height - 10)],
			align = 'l')
		contents = Row([finances, stock], align = 't', spacing = 32)
		contents.topleft = (32, 32)
		self.add(contents)

def CashView():
	return CompanyMoneyView('cash')

def IncomeView():
	return CompanyMoneyView('income')

def ExpenditureView():
	return CompanyMoneyView('expenditure')

def ProfitView():
	return CompanyMoneyView('profit')

def CompanyMoneyView(attr):
	def get():
		return getattr(game.company, attr)
	return MoneyView(get)

money_width = format_dollars(999999999)

def MoneyView(get):
	return ValueView(
		width = money_width,
		format_value = format_dollars,
		get_value = get,
		align = 'r')

#-----------------------------------------------------------------------

class StockView(PaletteView):

	cell_width = 200
	size_margin = 100
	border_width = 2
	margin = 4

	def __init__(self, height):
		cw = self.cell_width
		ch = self.font.get_linesize()
		nrows = height // ch
		PaletteView.__init__(self, (cw, ch), nrows, 1, scrolling = True)
	
	def num_items(self):
		n = len(game.company.material_stock_list)
		return n
	
	def draw_item(self, surf, n, rect):
		stock = game.company.material_stock_list[n]
		type = stock.material.formula()
		size = "%sx%s" % stock.sheet_size
		qty = str(stock.quantity)
		font = self.font
		fg = self.fg_color
		def blat(s, a, p):
			buf = font.render(s, True, fg)
			r = buf.get_rect()
			setattr(r, a, p)
			r.top = rect.top
			surf.blit(buf, r)
		blat(type, 'left', rect.left)
		blat(size, 'left', self.size_margin)
		blat(qty, 'right', rect.right)
