################################################################
#
#   Assembly Line - Part view
#
################################################################

from pygame import Rect
from albow.widget import Widget
from albow.controls import Label, Row, Column, ValueView

class PartView(Widget):

	def __init__(self, get_part, pixel_size, **kwds):
		Widget.__init__(self, **kwds)
		info_view = PartInfoView(get_part)
		pixels_view = PixelsView(pixel_size, get_part)
		self.add(Column([info_view, pixels_view], align = 'l'))
		self.shrink_wrap()


class PartInfoView(Widget):

	def __init__(self, get_part):
		Widget.__init__(self)
		self.get_part = get_part
		width_view = ValueView(width = "99", get_value = self.get_width)
		height_view = ValueView(width = "99", get_value = self.get_height)
		self.add(Row([
			Label("Size"), width_view, Label("x"), height_view
		]))
		self.shrink_wrap()
	
	def get_width(self):
		return self.index(self.get_part_size(), 0)

	def get_height(self):
		return self.index(self.get_part_size(), 1)
	
	def get_part_size(self):
		part = self.get_part()
		if part:
			return part.pixels.get_size()
	
	def index(self, seq, i):
		if seq:
			return seq[i]


class PixelsView(Widget):

	bg_color = (255, 255, 255)

	def __init__(self, pixel_size, get_part):
		self.pixel_size = pixel_size
		self.get_part = get_part
		size = 60 * pixel_size
		r = Rect(0, 0, size, size)
		Widget.__init__(self, r)

	def draw(self, surf):
		part = self.get_part()
		if part:
			pixels = part.pixels
			w, h = pixels.get_size()
			ps = self.pixel_size
			pw = ps - 1
			for j in xrange(h):
				for i in xrange(w):
					color = pixels.get_at((i, j))
					if color[3]:
						x = i * ps
						y = j * ps
						surf.fill(color, (x, y, pw, pw))
