################################################################
#
#   Assembly Line - Product view
#
################################################################

from pygame import Rect
from albow.widget import Widget
from albow.controls import Label, Row, Column
from albow.palette_view import PaletteView
from material import draw_formula
from part_view import PartInfoView, PixelsView

class ProductView(Widget):

	def __init__(self, height, pixel_size, get_product, **kwds):
		Widget.__init__(self, **kwds)
		self.get_product = get_product
		info_view = PartInfoView(self.get_part)
		pixels_view = PixelsView(pixel_size, self.get_part)
		material_view = ProductMaterialView(height, get_product)
		on_left = Column([info_view, pixels_view], align = 'l')
		on_right = Column([Label("Materials"), material_view], align = 'l')
		self.add(Row([on_left, on_right], align = 't'))
		self.shrink_wrap()
	
	def get_part(self):
		product = self.get_product()
		if product:
			return product.part


class ProductMaterialView(PaletteView):

	column_width = 100
	cell_height = 20
	#border_width = 2

	def __init__(self, height, get_product):
		self.get_product = get_product
		nrows = height // self.cell_height
		cell_size = (self.column_width, self.cell_height)
		PaletteView.__init__(self, cell_size, nrows, 1, scrolling = True)
	
	def num_items(self):
		prod = self.get_product()
		if prod:
			return len(prod.palette)
		else:
			return 0
	
	def item_is_selected(self, n):
		return False
	
	def draw_item(self, surf, n, rect):
		s = self.cell_height
		color = self.get_product().palette[n]
		r = Rect(2, 2, s - 2, s - 2)
		r.move_ip(rect.topleft)
		surf.fill(color, r)
		draw_formula(surf, color, (r.left + s + 5, r.top + 2), self.fg_color)

		