################################################################
#
#   Assembly Line - Statistics Page
#
################################################################

from albow.controls import Label, Row, Column, Grid, Frame, ValueView
from albow.palette_view import PaletteView
from albow.resource import get_font
from screen import ALScreen
from game import game
from format import format_dollars

#-----------------------------------------------------------------------

heading_font = get_font(15, "VeraBd.ttf")
data_font = get_font(12, "Vera.ttf")

#-----------------------------------------------------------------------

class StatsPage(ALScreen):
	
	bg_color = (147, 231, 255)

	def __init__(self, shell):
		ALScreen.__init__(self, shell)
		h = self.height - 90
		prod = Column([
			Label("Product Sales", font = heading_font),
			ProdStatsHeader(),
			ProductStatsView(h),
		], align = 'l')
		contents = prod
		contents.topleft = (32, 32)
		self.add(contents)
	
#-----------------------------------------------------------------------

def ProdStatsHeader():
	return Row([
		Label("Product", font = data_font, width = 100),
		Label("Sold",  font = data_font, width = 50, align = 'r'),
		Label("Trashed",  font = data_font, width = 60, align = 'r'),
		#Label("Freight Cost",  font = data_font, width = 80, align = 'r'),
		Label("Revenue",  font = data_font, width = 90, align = 'r'),
	], spacing = 0)

#-----------------------------------------------------------------------

class ProductStatsView(PaletteView):

	font = data_font

	name_margin = 0
	num_sold_margin = 150
	num_trashed_margin = 210
	#freight_cost_margin = 280
	revenue_margin = 300
	cell_width = 300

	def __init__(self, height):
		cell_height = self.font.get_linesize()
		nrows = height // cell_height
		csize = self.cell_width, cell_height
		PaletteView.__init__(self, csize, nrows, 1, scrolling = True)
	
	def num_items(self):
		return len(game.products)
	
	def draw_item(self, surf, n, rect):
		company = game.company
		product = game.products[n]
		hist = company.find_product_history(product)
		dt = self.draw_text
		dt(surf, rect, product.title, self.name_margin)
		dt(surf, rect, str(hist.number_sold), self.num_sold_margin, 'r')
		dt(surf, rect, str(hist.number_trashed), self.num_trashed_margin, 'r')
		#dt(surf, rect, format_dollars(hist.freight_cost), self.freight_cost_margin, 'r')
		dt(surf, rect, format_dollars(hist.revenue), self.revenue_margin, 'r')
	
	def draw_text(self, surf, rect, text, x, align = 'l'):
		buf = self.font.render(text, True, self.fg_color)
		r = buf.get_rect()
		r.top = rect.top
		if align == 'l':
			r.left = rect.left + x
		else:
			r.right = rect.left + x
		surf.blit(buf, r)
