################################################################
#
#   Assembly Line - Coordinate transformations
#
################################################################

from pygame import Rect

rotation_matrices = [
	( 1,  0,  0,  1),
	( 0, -1,  1,  0),
	(-1,  0,  0, -1),
	( 0,  1, -1,  0)
]

def add((x1, y1), (x2, y2)):
	return (x1 + x2, y1 + y2)

def sub((x1, y1), (x2, y2)):
	return (x1 - x2, y1 - y2)

def neg((x, y)):
	return (-x, -y)

def dot((x1, y1), (x2, y2)):
	return x1 * x2 + y1 * y2

def rotate_vector(r, (x, y)):
	m = rotation_matrices[r]
	return (m[0] * x + m[1] * y, m[2] * x + m[3] * y)

#----------------------------------------------------------------

class Transformation(object):
	#  rotation     int
	#  translation  vector

	def __init__(self, rotation, translation):
		self.rotation = rotation
		self.translation = translation
	
	def vector(self, v):
		return rotate_vector(self.rotation, v)

	def point(self, p):
		return add(rotate_vector(self.rotation, p), self.translation)
	
	def trans(self, t):
		return Transformation(
			(self.rotation + t.rotation) % 4,
			rotate_vector(self.rotation, t.translation))
	
	def rect(self, r):
		x, y = self.point(r.topleft)
		w, h = self.vector(r.size)
		if w < 0:
			x += w
			w = -w
		if h < 0:
			y += h
			h = -h
		return Rect(x, y, w, h)
	
	def draw_image(self, surf, images, p = (0, 0),
			index = None, ref = 'topleft', debug = False):
		r = images[0].get_rect()
		setattr(r, ref, p)
		r = self.rect(r)
		image = images[self.rotation % len(images)]
		if index is not None:
			image = image[index]
		surf.blit(image, r)

#----------------------------------------------------------------

identity = Transformation(0, (0, 0))
